==> openturns_1.5.orig.tar.bz2: openturns-1.5/lib/test/t_NegativeBinomialFactory_std.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  t_NegativeBinomialFactory_std.cxx
 *  @brief The test file of class NegativeBinomial for standard methods
 *
 *  Copyright 2005-2015 Airbus-EDF-IMACS-Phimeca
 *
 *  This library is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 *  @author dutka
 *  @date   2010-02-04 16:44:49 +0100 (jeu. 04 févr. 2010)
 */
#include "OT.hxx"
#include "OTtestcode.hxx"

using namespace OT;
using namespace OT::Test;

int main(int argc, char *argv[])
{
  TESTPREAMBLE;
  OStream fullprint(std::cout);
  setRandomGenerator();

  try
  {
    NegativeBinomial distribution(15, 0.7);
    UnsignedInteger size(10000);
    NumericalSample sample(distribution.getSample(size));
    NegativeBinomialFactory factory;
    CovarianceMatrix covariance;
    // Distribution estimatedDistribution(factory.build(sample, covariance));
    Distribution estimatedDistribution(factory.build(sample));
    fullprint << "Distribution          =" << distribution << std::endl;
    fullprint << "Estimated distribution=" << estimatedDistribution << std::endl;
    // fullprint << "Covariance=" << covariance << std::endl;
    estimatedDistribution = factory.build();
    fullprint << "Default distribution=" << estimatedDistribution << std::endl;
    estimatedDistribution = factory.build(distribution.getParametersCollection());
    fullprint << "Distribution from parameters=" << estimatedDistribution << std::endl;
    NegativeBinomial estimatedNegativeBinomial(factory.buildAsNegativeBinomial(sample));
    fullprint << "NegativeBinomial          =" << distribution << std::endl;
    fullprint << "Estimated negativeBinomial=" << estimatedNegativeBinomial << std::endl;
    estimatedNegativeBinomial = factory.buildAsNegativeBinomial();
    fullprint << "Default negativeBinomial=" << estimatedNegativeBinomial << std::endl;
    estimatedNegativeBinomial = factory.buildAsNegativeBinomial(distribution.getParametersCollection());
    fullprint << "NegativeBinomial from parameters=" << estimatedNegativeBinomial << std::endl;
  }
  catch (TestFailed & ex)
  {
    std::cerr << ex << std::endl;
    return ExitCode::Error;
  }


  return ExitCode::Success;
}

==> openturns_1.11.orig.tar.bz2: openturns-1.11/lib/test/t_NegativeBinomialFactory_std.cxx <==
//                                               -*- C++ -*-
/**
 *  @brief The test file of class NegativeBinomial for standard methods
 *
 *  Copyright 2005-2018 Airbus-EDF-IMACS-Phimeca
 *
 *  This library is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
#include "openturns/OT.hxx"
#include "openturns/OTtestcode.hxx"

using namespace OT;
using namespace OT::Test;

int main(int argc, char *argv[])
{
  TESTPREAMBLE;
  OStream fullprint(std::cout);
  setRandomGenerator();

  try
  {
    NegativeBinomial distribution(15, 0.7);
    UnsignedInteger size = 10000;
    Sample sample(distribution.getSample(size));
    NegativeBinomialFactory factory;
    CovarianceMatrix covariance;
    // Distribution estimatedDistribution(factory.build(sample, covariance));
    Distribution estimatedDistribution(factory.build(sample));
    fullprint << "Distribution          =" << distribution << std::endl;
    fullprint << "Estimated distribution=" << estimatedDistribution << std::endl;
    // fullprint << "Covariance=" << covariance << std::endl;
    estimatedDistribution = factory.build();
    fullprint << "Default distribution=" << estimatedDistribution << std::endl;
    estimatedDistribution = factory.build(distribution.getParameter());
    fullprint << "Distribution from parameters=" << estimatedDistribution << std::endl;
    NegativeBinomial estimatedNegativeBinomial(factory.buildAsNegativeBinomial(sample));
    fullprint << "NegativeBinomial          =" << distribution << std::endl;
    fullprint << "Estimated negativeBinomial=" << estimatedNegativeBinomial << std::endl;
    estimatedNegativeBinomial = factory.buildAsNegativeBinomial();
    fullprint << "Default negativeBinomial=" << estimatedNegativeBinomial << std::endl;
    estimatedNegativeBinomial = factory.buildAsNegativeBinomial(distribution.getParameter());
    fullprint << "NegativeBinomial from parameters=" << estimatedNegativeBinomial << std::endl;
  }
  catch (TestFailed & ex)
  {
    std::cerr << ex << std::endl;
    return ExitCode::Error;
  }


  return ExitCode::Success;
}
